@@ -1,10 +1,8 @@
 #' Start timer
 #'
-#' @importFrom pracma tic
-#'
 #' @description Start timer and write a custom text into the console.
 #'
-#' @param txt custom text
+#' @param txt custom text to be displayed.
 #'
 #' @examples
 #'
@@ -16,11 +14,13 @@
 #'
 #' @return None
 #'
-#' @seealso \code{\link{tock}}
+#' @seealso \code{\link{tock}} \code{\link{progress}} \code{\link{error}}
 #'
 #' @export
 
 tick = function(txt='Start') {
   cat(sprintf('%s',txt))
-  pracma::tic()
+  assign("tickTime", proc.time()[3], envir = .cooltools.env)
+  assign("progress_nchar", 0, envir = .cooltools.env)
+  assign("timerRunning", TRUE, envir = .cooltools.env)
 }
